# `Erutils`

The `Erutils` package is the most simple package that include some stuffs that i think that i use every day and build
them every day cause im to lazy to copy them from other projects :).

Erutils Package is a self-made package for self uses but if you find a way to use it to make you job easier.

feel free to use as you wish

Open [erfanzare Github](https://github.com/erfanzar/)

Open [Package Github](https://github.com/erfanzar/Erutils)

## 🚀 APIs

```python
import erutils
from erutils.loggers import *
# Loggers contain Logging stuff
from erutils.nn import *
# NN contain Nural networks built in Pytorch
from erutils.lightning import *
# Lightning Contain Some CV Packages
from erutils.utils import *
# Utils Contain Some Utils like reading files downloading and etc ...
```

## 🚀 About Me

Hi there 👋
I like to train deep neural nets on large datasets 🧠.
Among other things in this world:)

## License

[MIT](https://choosealicense.com/licenses/mit/)

## Used By

Private Project

## Author

- [@erfanzar](https://www.github.com/erfanzar)